@@ -26,62 +26,68 @@ import javax.inject.Inject;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Binding;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Invocation;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Binding;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.Invocation;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
-import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
-import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
-import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 
 @ApplicationScoped
 public class InvocationEditorDefinition extends BaseEditorDefinition<Invocation, InvocationGridData> {
 
     private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private ValueAndDataTypePopoverView.Presenter headerEditor;
 
     public InvocationEditorDefinition() {
         //CDI proxy
     }
 
     @Inject
-    public InvocationEditorDefinition(final @DMNEditor DMNGridPanel gridPanel,
-                                      final @DMNEditor DMNGridLayer gridLayer,
-                                      final DefinitionUtils definitionUtils,
+    public InvocationEditorDefinition(final DefinitionUtils definitionUtils,
                                       final SessionManager sessionManager,
-                                      final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                      final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                      final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                      final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
                                       final Event<ExpressionEditorChanged> editorSelectedEvent,
-                                      final CellEditorControlsView.Presenter cellEditorControls,
+                                      final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                                      final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                                       final ListSelectorView.Presenter listSelector,
                                       final TranslationService translationService,
-                                      final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
-        super(gridPanel,
-              gridLayer,
-              definitionUtils,
+                                      final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                                      final ValueAndDataTypePopoverView.Presenter headerEditor,
+                                      final @DMNEditor ReadOnlyProvider readOnlyProvider) {
+        super(definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
-              cellEditorControls,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               listSelector,
-              translationService);
+              translationService,
+              readOnlyProvider);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
     }
 
     @Override
@@ -101,6 +107,7 @@ public class InvocationEditorDefinition extends BaseEditorDefinition<Invocation,
 
     @Override
     public void enrich(final Optional<String> nodeUUID,
+                       final HasExpression hasExpression,
                        final Optional<Invocation> expression) {
         expression.ifPresent(invocation -> {
             final LiteralExpression literalExpression = new LiteralExpression();
@@ -120,38 +127,42 @@ public class InvocationEditorDefinition extends BaseEditorDefinition<Invocation,
     }
 
     @Override
-    public Optional<BaseExpressionGrid> getEditor(final GridCellTuple parent,
-                                                  final Optional<String> nodeUUID,
-                                                  final HasExpression hasExpression,
-                                                  final Optional<Invocation> expression,
-                                                  final Optional<HasName> hasName,
-                                                  final int nesting) {
+    public Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>> getEditor(final GridCellTuple parent,
+                                                                                                                         final Optional<String> nodeUUID,
+                                                                                                                         final HasExpression hasExpression,
+                                                                                                                         final Optional<HasName> hasName,
+                                                                                                                         final boolean isOnlyVisualChangeAllowed,
+                                                                                                                         final int nesting) {
         return Optional.of(new InvocationGrid(parent,
                                               nodeUUID,
                                               hasExpression,
-                                              expression,
                                               hasName,
-                                              gridPanel,
-                                              gridLayer,
-                                              makeGridData(expression),
+                                              getGridPanel(),
+                                              getGridLayer(),
+                                              makeGridData(() -> Optional.ofNullable((Invocation) hasExpression.getExpression())),
                                               definitionUtils,
                                               sessionManager,
                                               sessionCommandManager,
                                               canvasCommandFactory,
                                               editorSelectedEvent,
-                                              cellEditorControls,
+                                              refreshFormPropertiesEvent,
+                                              domainObjectSelectionEvent,
+                                              getCellEditorControls(),
                                               listSelector,
                                               translationService,
+                                              isOnlyVisualChangeAllowed,
                                               nesting,
-                                              expressionEditorDefinitionsSupplier));
+                                              expressionEditorDefinitionsSupplier,
+                                              headerEditor,
+                                              readOnlyProvider));
     }
 
     @Override
-    protected InvocationGridData makeGridData(final Optional<Invocation> expression) {
+    protected InvocationGridData makeGridData(final Supplier<Optional<Invocation>> expression) {
         return new InvocationGridData(new DMNGridData(),
                                       sessionManager,
                                       sessionCommandManager,
                                       expression,
-                                      gridLayer::batch);
+                                      getGridLayer()::batch);
     }
 }
