@@ -32,7 +32,7 @@ import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
@@ -40,11 +40,11 @@ import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
@@ -52,7 +52,7 @@ import org.uberfire.ext.wires.core.grids.client.model.GridData;
 @ApplicationScoped
 public class LiteralExpressionEditorDefinition extends BaseEditorDefinition<LiteralExpression, DMNGridData> {
 
-    private NameAndDataTypePopoverView.Presenter headerEditor;
+    private ValueAndDataTypePopoverView.Presenter headerEditor;
 
     public LiteralExpressionEditorDefinition() {
         //CDI proxy
@@ -61,14 +61,15 @@ public class LiteralExpressionEditorDefinition extends BaseEditorDefinition<Lite
     @Inject
     public LiteralExpressionEditorDefinition(final DefinitionUtils definitionUtils,
                                              final SessionManager sessionManager,
-                                             final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                             final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                              final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
                                              final Event<ExpressionEditorChanged> editorSelectedEvent,
                                              final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
                                              final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                                              final ListSelectorView.Presenter listSelector,
                                              final TranslationService translationService,
-                                             final NameAndDataTypePopoverView.Presenter headerEditor) {
+                                             final ValueAndDataTypePopoverView.Presenter headerEditor,
+                                             final @DMNEditor ReadOnlyProvider readOnlyProvider) {
         super(definitionUtils,
               sessionManager,
               sessionCommandManager,
@@ -77,7 +78,8 @@ public class LiteralExpressionEditorDefinition extends BaseEditorDefinition<Lite
               refreshFormPropertiesEvent,
               domainObjectSelectionEvent,
               listSelector,
-              translationService);
+              translationService,
+              readOnlyProvider);
         this.headerEditor = headerEditor;
     }
 
@@ -122,7 +124,8 @@ public class LiteralExpressionEditorDefinition extends BaseEditorDefinition<Lite
                                                      translationService,
                                                      isOnlyVisualChangeAllowed,
                                                      nesting,
-                                                     headerEditor));
+                                                     headerEditor,
+                                                     readOnlyProvider));
     }
 
     @Override
