@@ -27,13 +27,13 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Decision;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Decision;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextGrid;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseDelegatingExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
@@ -49,6 +49,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.UpdateElementPropertyCommand;
@@ -175,7 +176,10 @@ public abstract class BaseLiteralExpressionGridTest<G extends BaseDelegatingExpr
     protected EventSourceMock<DomainObjectSelectionEvent> domainObjectSelectionEvent;
 
     @Mock
-    protected NameAndDataTypePopoverView.Presenter headerEditor;
+    protected ValueAndDataTypePopoverView.Presenter headerEditor;
+
+    @Mock
+    protected ReadOnlyProvider readOnlyProvider;
 
     @Captor
     protected ArgumentCaptor<CompositeCommand> compositeCommandCaptor;
@@ -300,7 +304,7 @@ public abstract class BaseLiteralExpressionGridTest<G extends BaseDelegatingExpr
     public void testInitialColumnWidthsFromDefinition() {
         setupGrid(0);
 
-        assertComponentWidths(DMNGridColumn.DEFAULT_WIDTH);
+        assertComponentWidths(getDefaultWidth());
     }
 
     @Test
@@ -422,5 +426,9 @@ public abstract class BaseLiteralExpressionGridTest<G extends BaseDelegatingExpr
 
         verify(command).execute();
     }
+
+    protected double getDefaultWidth() {
+        return DMNGridColumn.DEFAULT_WIDTH;
+    }
 }
 
