@@ -18,21 +18,27 @@ package org.kie.workbench.common.dmn.project.client.editor;
 
 import java.lang.annotation.Annotation;
 import java.util.function.Consumer;
+import java.util.function.Supplier;
 
+import javax.enterprise.event.Event;
+
+import com.google.gwt.user.client.Command;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import com.google.gwtmockito.WithClassesToStub;
 import elemental2.dom.HTMLElement;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.commands.general.NavigateToExpressionEditorCommand;
-import org.kie.workbench.common.dmn.client.decision.DecisionNavigatorDock;
+import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
+import org.kie.workbench.common.dmn.client.docks.navigator.common.LazyCanvasFocusUtils;
+import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
 import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
-import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEvent;
@@ -40,32 +46,55 @@ import org.kie.workbench.common.dmn.client.editors.types.DataTypesPage;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
 import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
+import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
 import org.kie.workbench.common.dmn.project.client.resources.i18n.DMNProjectClientConstants;
 import org.kie.workbench.common.dmn.project.client.type.DMNDiagramResourceType;
+import org.kie.workbench.common.services.shared.resources.PerspectiveIds;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.components.layout.LayoutHelper;
 import org.kie.workbench.common.stunner.core.client.components.layout.OpenDiagramLayoutExecutor;
+import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
+import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationPage;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.kie.workbench.common.stunner.kogito.client.editor.AbstractDiagramEditorMenuSessionItems;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
+import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorCore;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorTest;
-import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectEditorMenuSessionItems;
+import org.kie.workbench.common.stunner.project.client.editor.ProjectDiagramEditorProxy;
+import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
+import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
+import org.kie.workbench.common.stunner.project.diagram.editor.ProjectDiagramResource;
 import org.kie.workbench.common.widgets.client.docks.DefaultEditorDock;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
-import org.kie.workbench.common.workbench.client.PerspectiveIds;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.InOrder;
 import org.mockito.Mock;
+import org.uberfire.client.views.pfly.multipage.MultiPageEditorSelectedPageEvent;
+import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
+import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.kie.workbench.common.dmn.project.client.editor.DMNDiagramEditor.DATA_TYPES_PAGE_INDEX;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
@@ -96,6 +125,9 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private DMNEditorSession dmnEditorSession;
 
+    @Mock
+    private DMNEditorSession defaultEditorSession;
+
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
@@ -112,7 +144,7 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     private EditExpressionEvent editExpressionEvent;
 
     @Mock
-    private DMNProjectEditorMenuSessionItems dmnProjectMenuSessionItems;
+    private DMNEditorMenuSessionItems dmnProjectMenuSessionItems;
 
     @Mock
     private LayoutHelper layoutHelper;
@@ -126,9 +158,6 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private IncludedModelsPage includedModelsPage;
 
-    @Mock
-    private IncludedModelsPageStateProviderImpl importsPageProvider;
-
     @Mock
     private MultiPageEditor multiPage;
 
@@ -149,9 +178,27 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private HTMLElement searchBarComponentViewElement;
 
+    @Mock
+    private MonacoFEELInitializer feelInitializer;
+
     @Mock
     private ElementWrapperWidget searchBarComponentWidget;
 
+    @Mock
+    private ReadOnlyProvider readOnlyProvider;
+
+    @Mock
+    private HTMLElement drdNameChangerElement;
+
+    @Mock
+    private DRDNameChanger drdNameChanger;
+
+    @Mock
+    private LazyCanvasFocusUtils lazyCanvasFocusUtils;
+
+    @Mock
+    private ElementWrapperWidget drdNameWidget;
+
     @Captor
     private ArgumentCaptor<Consumer<String>> errorConsumerCaptor;
 
@@ -163,11 +210,15 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Override
     public void setUp() {
         super.setUp();
-
+        when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
         when(sessionEditorPresenter.getInstance()).thenReturn(dmnEditorSession);
         when(dmnEditorSession.getExpressionEditor()).thenReturn(expressionEditor);
+        when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
+        when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(searchBarComponent.getView()).thenReturn(searchBarComponentView);
         when(searchBarComponentView.getElement()).thenReturn(searchBarComponentViewElement);
+        when(drdNameChanger.getElement()).thenReturn(drdNameChangerElement);
+        doReturn(drdNameWidget).when(diagramEditor).getWidget(drdNameChangerElement);
     }
 
     @Override
@@ -182,34 +233,35 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Override
     protected AbstractProjectDiagramEditor createDiagramEditor() {
         diagramEditor = spy(new DMNDiagramEditor(view,
-                                                 documentationView,
-                                                 placeManager,
-                                                 errorPopupPresenter,
-                                                 changeTitleNotificationEvent,
-                                                 savePopUpPresenter,
-                                                 (DMNDiagramResourceType) getResourceType(),
-                                                 clientProjectDiagramService,
+                                                 xmlEditorView,
                                                  sessionEditorPresenters,
                                                  sessionViewerPresenters,
-                                                 (DMNProjectEditorMenuSessionItems) getMenuSessionItems(),
                                                  onDiagramFocusEvent,
                                                  onDiagramLostFocusEvent,
-                                                 refreshFormPropertiesEvent,
-                                                 projectMessagesListener,
+                                                 notificationEvent,
+                                                 errorPopupPresenter,
                                                  diagramClientErrorHandler,
+                                                 documentationView,
+                                                 (DMNDiagramResourceType) getResourceType(),
+                                                 (DMNEditorMenuSessionItems) getMenuSessionItems(),
+                                                 projectMessagesListener,
                                                  translationService,
-                                                 xmlEditorView,
+                                                 clientProjectDiagramService,
                                                  projectDiagramResourceServiceCaller,
                                                  sessionManager,
                                                  sessionCommandManager,
+                                                 refreshFormPropertiesEvent,
                                                  decisionNavigatorDock,
                                                  layoutHelper,
-                                                 dataTypesPage,
                                                  layoutExecutor,
+                                                 dataTypesPage,
                                                  includedModelsPage,
-                                                 importsPageProvider,
                                                  editorSearchIndex,
-                                                 searchBarComponent) {
+                                                 searchBarComponent,
+                                                 feelInitializer,
+                                                 readOnlyProvider,
+                                                 drdNameChanger,
+                                                 lazyCanvasFocusUtils) {
             {
                 docks = DMNDiagramEditorTest.this.docks;
                 fileMenuBuilder = DMNDiagramEditorTest.this.fileMenuBuilder;
@@ -220,22 +272,68 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
                 alertsButtonMenuItemBuilder = DMNDiagramEditorTest.this.alertsButtonMenuItemBuilder;
                 kieView = DMNDiagramEditorTest.this.kieView;
                 overviewWidget = DMNDiagramEditorTest.this.overviewWidget;
-                notification = DMNDiagramEditorTest.this.notification;
+                notification = DMNDiagramEditorTest.this.notificationEvent;
+                placeManager = DMNDiagramEditorTest.this.placeManager;
+                changeTitleNotification = DMNDiagramEditorTest.this.changeTitleNotificationEvent;
+                savePopUpPresenter = DMNDiagramEditorTest.this.savePopUpPresenter;
+            }
+
+            @Override
+            protected AbstractProjectDiagramEditorCore<ProjectMetadata, ProjectDiagram, ProjectDiagramResource, ProjectDiagramEditorProxy<ProjectDiagramResource>> makeCore(final AbstractProjectDiagramEditor.View view,
+                                                                                                                                                                            final TextEditorView xmlEditorView,
+                                                                                                                                                                            final Event<NotificationEvent> notificationEvent,
+                                                                                                                                                                            final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances,
+                                                                                                                                                                            final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances,
+                                                                                                                                                                            final AbstractDiagramEditorMenuSessionItems<?> menuSessionItems,
+                                                                                                                                                                            final ErrorPopupPresenter errorPopupPresenter,
+                                                                                                                                                                            final DiagramClientErrorHandler diagramClientErrorHandler,
+                                                                                                                                                                            final ClientTranslationService translationService) {
+                presenterCore = spy(super.makeCore(view,
+                                                   xmlEditorView,
+                                                   notificationEvent,
+                                                   editorSessionPresenterInstances,
+                                                   viewerSessionPresenterInstances,
+                                                   menuSessionItems,
+                                                   errorPopupPresenter,
+                                                   diagramClientErrorHandler,
+                                                   translationService));
+                this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilderMock;
+                return presenterCore;
+            }
+
+            @Override
+            public boolean isReadOnly() {
+                return DMNDiagramEditorTest.this.isReadOnly;
+            }
+
+            @Override
+            ElementWrapperWidget<?> getWidget(final HTMLElement element) {
+                return searchBarComponentWidget;
+            }
+
+            @Override
+            public SessionPresenter<? extends ClientSession, ?, Diagram> getSessionPresenter() {
+                return sessionViewerPresenter;
             }
         });
 
-        doReturn(searchBarComponentWidget).when(diagramEditor).getWidget(searchBarComponentViewElement);
-
         return diagramEditor;
     }
 
     @Override
-    protected AbstractProjectEditorMenuSessionItems getMenuSessionItems() {
+    protected AbstractDiagramEditorMenuSessionItems getMenuSessionItems() {
         return dmnProjectMenuSessionItems;
     }
 
     @Test
     public void testInit() {
+
+        final Supplier<Boolean> isDataTypesTabActiveSupplier = () -> true;
+        final Supplier<Integer> currentContentHashSupplier = () -> 123;
+
+        doReturn(isDataTypesTabActiveSupplier).when(diagramEditor).getIsDataTypesTabActiveSupplier();
+        doReturn(currentContentHashSupplier).when(diagramEditor).getGetCurrentContentHashSupplier();
+
         diagramEditor.init();
 
         //DMNProjectEditorMenuSessionItems.setErrorConsumer(..) is called several times so just check the last invocation
@@ -245,6 +343,20 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
         verify(view).hideBusyIndicator();
         verify(errorPopupPresenter, never()).showMessage(anyString());
+        verify(editorSearchIndex).setIsDataTypesTabActiveSupplier(isDataTypesTabActiveSupplier);
+        verify(editorSearchIndex).setCurrentAssetHashcodeSupplier(currentContentHashSupplier);
+    }
+
+    @Test
+    public void testGetIsDataTypesTabActiveSupplierWhenDataTypesTabIsActive() {
+        when(multiPage.selectedPage()).thenReturn(DATA_TYPES_PAGE_INDEX);
+        assertTrue(diagramEditor.getIsDataTypesTabActiveSupplier().get());
+    }
+
+    @Test
+    public void testGetIsDataTypesTabActiveSupplierWhenDataTypesTabIsNotActive() {
+        when(multiPage.selectedPage()).thenReturn(DATA_TYPES_PAGE_INDEX + 1);
+        assertFalse(diagramEditor.getIsDataTypesTabActiveSupplier().get());
     }
 
     @Test
@@ -293,17 +405,15 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
         when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
-        when(importsPageProvider.withDiagram(diagram)).thenReturn(importsPageProvider);
 
         open();
 
-        final InOrder inOrder = inOrder(decisionNavigatorDock);
-        inOrder.verify(decisionNavigatorDock).setupCanvasHandler(eq(canvasHandler));
-
-        verify(expressionEditor).setToolbarStateHandler(any(ProjectToolbarStateHandler.class));
+        verify(decisionNavigatorDock).reload();
+        verify(expressionEditor).setToolbarStateHandler(any(DMNProjectToolbarStateHandler.class));
         verify(dataTypesPage).reload();
         verify(layoutHelper).applyLayout(diagram, layoutExecutor);
-        verify(includedModelsPage).setup(importsPageProvider);
+        verify(includedModelsPage).reload();
+        verify(lazyCanvasFocusUtils).releaseFocus();
     }
 
     @Test
@@ -311,11 +421,12 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     public void testOnDiagramLoadWhenCanvasHandlerIsNull() {
         diagramEditor.onDiagramLoad();
 
-        verify(expressionEditor, never()).setToolbarStateHandler(any(ProjectToolbarStateHandler.class));
-        verify(decisionNavigatorDock, never()).setupCanvasHandler(any());
+        verify(expressionEditor, never()).setToolbarStateHandler(any(DMNProjectToolbarStateHandler.class));
+        verify(decisionNavigatorDock, never()).reload();
         verify(decisionNavigatorDock, never()).open();
         verify(dataTypesPage, never()).reload();
-        verify(includedModelsPage, never()).setup(any());
+        verify(includedModelsPage, never()).reload();
+        verify(lazyCanvasFocusUtils, never()).releaseFocus();
     }
 
     @Test
@@ -347,21 +458,20 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
         diagramEditor.onEditExpressionEvent(editExpressionEvent);
 
+        verify(searchBarComponent).disableSearch();
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               any(NavigateToExpressionEditorCommand.class));
     }
 
     @Test
     public void testOnDataTypePageNavTabActiveEvent() {
-
         diagramEditor.onDataTypePageNavTabActiveEvent(mock(DataTypePageTabActiveEvent.class));
 
-        verify(multiPage).selectPage(3);
+        verify(multiPage).selectPage(DATA_TYPES_PAGE_INDEX);
     }
 
     @Test
     public void testOnDataTypeEditModeToggleWhenEditModeIsEnabled() {
-
         final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
 
         doNothing().when(diagramEditor).disableMenuItem(any());
@@ -374,7 +484,6 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
     @Test
     public void testOnDataTypeEditModeToggleWhenEditModeIsNotEnabled() {
-
         final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
 
         doNothing().when(diagramEditor).enableMenuItem(any());
@@ -416,10 +525,10 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
         final String xml = "xml";
 
-        openInvalidBPMNFile(xml);
+        openInvalidFile(xml);
 
         final ArgumentCaptor<NotificationEvent> notificationEventCaptor = ArgumentCaptor.forClass(NotificationEvent.class);
-        verify(notification).fire(notificationEventCaptor.capture());
+        verify(notificationEvent).fire(notificationEventCaptor.capture());
 
         final NotificationEvent notificationEvent = notificationEventCaptor.getValue();
         assertEquals(DMNProjectClientConstants.DMNDiagramParsingErrorMessage,
@@ -431,4 +540,79 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         final Overview overview = assertBasicStunnerSaveOperation(false);
         assertSaveOperation(overview);
     }
+
+    @Test
+    public void testOnMultiPageEditorSelectedPageEvent() {
+
+        final SessionPresenter sessionPresenter = mock(SessionPresenter.class);
+
+        doReturn(sessionPresenter).when(diagramEditor).getSessionPresenter();
+        when(sessionPresenter.getInstance()).thenReturn(dmnEditorSession);
+        when(sessionPresenter.getView()).thenReturn(sessionPresenterView);
+        when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
+
+        open();
+
+        diagramEditor.onMultiPageEditorSelectedPageEvent(mock(MultiPageEditorSelectedPageEvent.class));
+
+        verify(searchBarComponent).disableSearch();
+    }
+
+    @Test
+    public void testOnMultiPageEditorSelectedPageEventWhenEditorIsNotInTheSameSession() {
+
+        final SessionPresenter sessionPresenter = mock(SessionPresenter.class);
+
+        doReturn(sessionPresenter).when(diagramEditor).getSessionPresenter();
+        when(sessionPresenter.getInstance()).thenReturn(dmnEditorSession);
+        when(sessionPresenter.getView()).thenReturn(sessionPresenterView);
+        when(sessionManager.getCurrentSession()).thenReturn(defaultEditorSession);
+        when(defaultEditorSession.getExpressionEditor()).thenReturn(expressionEditor);
+
+        open();
+
+        diagramEditor.onMultiPageEditorSelectedPageEvent(mock(MultiPageEditorSelectedPageEvent.class));
+
+        verify(searchBarComponent, never()).disableSearch();
+    }
+
+    @Test
+    public void testOnRefreshFormPropertiesEvent() {
+        diagramEditor.onRefreshFormPropertiesEvent(mock(RefreshFormPropertiesEvent.class));
+        verify(searchBarComponent).disableSearch();
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testTabContentOrdering() {
+        when(documentationView.isEnabled()).thenReturn(Boolean.TRUE);
+        when(documentationView.initialize(diagram)).thenReturn(documentationView);
+        when(kieView.getMultiPage()).thenReturn(multiPage);
+
+        open();
+
+        final InOrder inOrder = inOrder(kieView, multiPage);
+        inOrder.verify(kieView).addMainEditorPage(view);
+        inOrder.verify(kieView).addPage(any(DocumentationPage.class));
+        inOrder.verify(multiPage).addPage(dataTypesPage);
+        inOrder.verify(multiPage).addPage(includedModelsPage);
+        inOrder.verify(kieView).addOverviewPage(eq(overviewWidget), any(Command.class));
+    }
+
+    @Test
+    @Override
+    public void testLoadContentWithValidFile() {
+        super.testLoadContentWithValidFile();
+
+        verify(layoutHelper).applyLayout(eq(diagram), eq(layoutExecutor));
+        verify(feelInitializer).initializeFEELEditor();
+    }
+
+    @Test
+    @Override
+    public void testLoadContentWithInvalidFile() {
+        super.testLoadContentWithInvalidFile();
+
+        verify(feelInitializer, never()).initializeFEELEditor();
+    }
 }
