@@ -34,9 +34,11 @@ import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.commands.general.NavigateToExpressionEditorCommand;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
+import org.kie.workbench.common.dmn.client.docks.navigator.common.LazyCanvasFocusUtils;
+import org.kie.workbench.common.dmn.client.docks.navigator.drds.DMNDiagramsSession;
+import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
 import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
-import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.toolbar.ToolbarStateHandler;
@@ -44,9 +46,11 @@ import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEv
 import org.kie.workbench.common.dmn.client.editors.types.DataTypesPage;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
+import org.kie.workbench.common.dmn.client.marshaller.DMNMarshallerService;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
 import org.kie.workbench.common.dmn.client.widgets.toolbar.DMNEditorToolbar;
+import org.kie.workbench.common.dmn.client.widgets.toolbar.DMNLayoutHelper;
 import org.kie.workbench.common.dmn.showcase.client.perspectives.AuthoringPerspective;
 import org.kie.workbench.common.dmn.showcase.client.services.DMNShowcaseDiagramService;
 import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDiagramDock;
@@ -68,7 +72,6 @@ import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.event.OnSessionErrorEvent;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
@@ -85,6 +88,8 @@ import org.kie.workbench.common.stunner.forms.client.event.RefreshFormProperties
 import org.kie.workbench.common.stunner.kogito.client.docks.DiagramEditorPropertiesDock;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
+import org.uberfire.backend.vfs.Path;
+import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.client.annotations.WorkbenchContextId;
 import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
@@ -109,8 +114,11 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
 
     public static final String EDITOR_ID = "DMNDiagramEditor";
 
+    private static final String ROOT = "default://master@system/stunner/diagrams";
+
     //Editor tabs: [0] Main editor, [1] Documentation, [2] Data-Types, [3] Imported Models
-    public static final int DATA_TYPES_PAGE_INDEX = 2;
+    static final int MAIN_EDITOR_PAGE_INDEX = 0;
+    static final int DATA_TYPES_PAGE_INDEX = 2;
 
     private static Logger LOGGER = Logger.getLogger(DMNDiagramEditor.class.getName());
 
@@ -130,7 +138,6 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
 
     private final DataTypesPage dataTypesPage;
     private final IncludedModelsPage includedModelsPage;
-    private final IncludedModelsPageStateProviderImpl importsPageProvider;
     private final DocumentationView<Diagram> documentationView;
     private final DMNEditorSearchIndex editorSearchIndex;
     private final SearchBarComponent<DMNSearchableElement> searchBarComponent;
@@ -143,14 +150,19 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
     private final ScreenErrorView screenErrorView;
     private final KieEditorWrapperView kieView;
     private final MonacoFEELInitializer feelInitializer;
+    private final DMNDiagramsSession dmnDiagramsSession;
+    private final DMNMarshallerService marshallerService;
+    private final DRDNameChanger drdNameChanger;
+    private final LazyCanvasFocusUtils lazyCanvasFocusUtils;
 
     private PlaceRequest placeRequest;
     private String title = "Authoring Screen";
     private Menus menu = null;
+    private Metadata metadata = null;
 
     @Inject
     public DMNDiagramEditor(final SessionManager sessionManager,
-                            final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                            final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                             final SessionEditorPresenter<EditorSession> presenter,
                             final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
                             final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
@@ -158,11 +170,10 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
                             final DecisionNavigatorDock decisionNavigatorDock,
                             final DiagramEditorPropertiesDock diagramPropertiesDock,
                             final PreviewDiagramDock diagramPreviewAndExplorerDock,
-                            final LayoutHelper layoutHelper,
+                            final @DMNEditor DMNLayoutHelper layoutHelper,
                             final OpenDiagramLayoutExecutor layoutExecutor,
                             final DataTypesPage dataTypesPage,
                             final IncludedModelsPage includedModelsPage,
-                            final IncludedModelsPageStateProviderImpl importsPageProvider,
                             final @DMNEditor DocumentationView<Diagram> documentationView,
                             final DMNEditorSearchIndex editorSearchIndex,
                             final SearchBarComponent<DMNSearchableElement> searchBarComponent,
@@ -173,7 +184,11 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
                             final ScreenPanelView screenPanelView,
                             final ScreenErrorView screenErrorView,
                             final KieEditorWrapperView kieView,
-                            final MonacoFEELInitializer feelInitializer) {
+                            final MonacoFEELInitializer feelInitializer,
+                            final DMNDiagramsSession dmnDiagramsSession,
+                            final DMNMarshallerService marshallerService,
+                            final DRDNameChanger drdNameChanger,
+                            final LazyCanvasFocusUtils lazyCanvasFocusUtils) {
         this.sessionManager = sessionManager;
         this.sessionCommandManager = sessionCommandManager;
         this.presenter = presenter;
@@ -190,7 +205,6 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
 
         this.dataTypesPage = dataTypesPage;
         this.includedModelsPage = includedModelsPage;
-        this.importsPageProvider = importsPageProvider;
         this.documentationView = documentationView;
         this.editorSearchIndex = editorSearchIndex;
         this.searchBarComponent = searchBarComponent;
@@ -203,6 +217,10 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
         this.screenErrorView = screenErrorView;
         this.kieView = kieView;
         this.feelInitializer = feelInitializer;
+        this.dmnDiagramsSession = dmnDiagramsSession;
+        this.marshallerService = marshallerService;
+        this.drdNameChanger = drdNameChanger;
+        this.lazyCanvasFocusUtils = lazyCanvasFocusUtils;
     }
 
     @PostConstruct
@@ -217,12 +235,16 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
         kieView.getMultiPage().addPage(getDocumentationPage());
         kieView.getMultiPage().addPage(dataTypesPage);
         kieView.getMultiPage().addPage(includedModelsPage);
-        feelInitializer.initializeFEELEditor();
 
         setupEditorSearchIndex();
         setupSearchComponent();
     }
 
+    private void setupSessionHeaderContainer() {
+        drdNameChanger.setSessionPresenterView(presenter.getView());
+        presenter.getView().setSessionHeaderContainer(getWidget(drdNameChanger.getElement()));
+    }
+
     private void setupEditorSearchIndex() {
         editorSearchIndex.setCurrentAssetHashcodeSupplier(getHashcodeSupplier());
         editorSearchIndex.setIsDataTypesTabActiveSupplier(getIsDataTypesTabActiveSupplier());
@@ -260,6 +282,7 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
         this.menu = makeMenuBar();
         final String name = placeRequest.getParameter("name",
                                                       "");
+
         final boolean isCreate = name == null || name.trim().length() == 0;
         final Command callback = getOnStartupDiagramEditorCallback();
         if (isCreate) {
@@ -377,11 +400,9 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
                                          new ServiceCallback<Diagram>() {
                                              @Override
                                              public void onSuccess(final Diagram diagram) {
-                                                 final Metadata metadata = diagram.getMetadata();
-                                                 metadata.setShapeSetId(shapeSetId);
-                                                 metadata.setTitle(title);
-                                                 open(diagram,
-                                                      callback);
+                                                 marshallerService.setOnDiagramLoad(onDiagramLoadCallback(callback));
+                                                 marshallerService.registerDiagramInstance(diagram, title, shapeSetId);
+                                                 open(diagram, callback);
                                              }
 
                                              @Override
@@ -392,16 +413,23 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
                                          });
     }
 
-    private Metadata buildMetadata(final String defSetId,
-                                   final String shapeSetId,
-                                   final String title) {
+    Metadata buildMetadata(final String defSetId,
+                           final String shapeSetId,
+                           final String title) {
+        final Path root = PathFactory.newPath(".", ROOT);
         return new MetadataImpl.MetadataImplBuilder(defSetId,
                                                     definitionManager)
                 .setTitle(title)
+                .setRoot(root)
+                .setPath(PathFactory.newPath(title, root.toURI() + "/" + uuid() + ".dmn"))
                 .setShapeSetId(shapeSetId)
                 .build();
     }
 
+    String uuid() {
+        return UUID.uuid(8);
+    }
+
     public void onMultiPageEditorSelectedPageEvent(final @Observes MultiPageEditorSelectedPageEvent event) {
         searchBarComponent.disableSearch();
     }
@@ -413,26 +441,31 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
     private void load(final String name,
                       final Command callback) {
         BusyPopup.showMessage("Loading");
-        diagramService.loadByName(name,
-                                  new ServiceCallback<Diagram>() {
-                                      @Override
-                                      public void onSuccess(final Diagram diagram) {
-                                          open(diagram,
-                                               callback);
-                                      }
+        diagramService.loadByName(name, onDiagramLoadCallback(callback));
+    }
 
-                                      @Override
-                                      public void onError(final ClientRuntimeError error) {
-                                          showError(error);
-                                          callback.execute();
-                                      }
-                                  });
+    ServiceCallback<Diagram> onDiagramLoadCallback(final Command callback) {
+        return new ServiceCallback<Diagram>() {
+            @Override
+            public void onSuccess(final Diagram diagram) {
+                open(diagram, callback);
+                DMNDiagramEditor.this.metadata = diagram.getMetadata();
+                DMNDiagramEditor.this.kieView.getMultiPage().selectPage(MAIN_EDITOR_PAGE_INDEX);
+            }
+
+            @Override
+            public void onError(final ClientRuntimeError error) {
+                showError(error);
+                callback.execute();
+            }
+        };
     }
 
     void open(final Diagram diagram,
               final Command callback) {
         screenPanelView.setWidget(presenter.getView());
         layoutHelper.applyLayout(diagram, layoutExecutor);
+        feelInitializer.initializeFEELEditor();
         presenter
                 .withToolbar(true)
                 .withPalette(true)
@@ -444,9 +477,11 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
                           expressionEditor.setToolbarStateHandler(toolbarStateHandler);
                           dataTypesPage.reload();
                           dataTypesPage.enableShortcuts();
-                          includedModelsPage.setup(importsPageProvider.withDiagram(diagram));
-                          setupCanvasHandler(presenter.getInstance());
+                          includedModelsPage.reload();
+                          lazyCanvasFocusUtils.releaseFocus();
+                          setupCanvasHandler();
                           openDock();
+                          setupSessionHeaderContainer();
                           callback.execute();
                       }));
     }
@@ -469,10 +504,15 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
         destroyDock();
         destroySession();
         dataTypesPage.disableShortcuts();
+        dmnDiagramsSession.destroyState(getMetadata());
     }
 
-    void setupCanvasHandler(final EditorSession session) {
-        decisionNavigatorDock.setupCanvasHandler(session.getCanvasHandler());
+    Metadata getMetadata() {
+        return metadata;
+    }
+
+    void setupCanvasHandler() {
+        decisionNavigatorDock.reload();
     }
 
     void openDock() {
@@ -551,7 +591,7 @@ public class DMNDiagramEditor implements KieEditorWrapperView.KieEditorWrapperPr
         return null != getCanvasHandler() ? getCanvasHandler().getDiagram() : null;
     }
 
-    private void showError(final ClientRuntimeError error) {
+    void showError(final ClientRuntimeError error) {
         screenErrorView.showError(error);
         screenPanelView.setWidget(screenErrorView.asWidget());
         log(Level.SEVERE,
