@@ -23,36 +23,33 @@ import com.ait.lienzo.client.core.shape.wires.IContainmentAcceptor;
 import com.ait.lienzo.client.core.shape.wires.IDockingAcceptor;
 import com.ait.lienzo.client.core.shape.wires.WiresConnection;
 import com.ait.lienzo.client.core.shape.wires.WiresMagnet;
+import com.ait.lienzo.client.core.shape.wires.WiresManager;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
-import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
+import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvasView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.SetConnectionSourceNodeCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.command.SetConnectionTargetNodeCommand;
-import org.kie.workbench.common.stunner.core.client.canvas.event.CancelCanvasAction;
+import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasHighlight;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
-import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
 import org.kie.workbench.common.stunner.core.graph.content.view.MagnetConnection;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
-import org.mockito.InOrder;
 import org.mockito.Mock;
-import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -61,7 +58,6 @@ import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doAnswer;
-import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
@@ -78,9 +74,13 @@ public class ConnectionAcceptorControlImplTest {
     @Mock
     private AbstractCanvasHandler canvasHandler;
     @Mock
-    private AbstractCanvas canvas;
+    private CanvasHighlight highlight;
     @Mock
-    private WiresCanvas.View canvasView;
+    private WiresCanvas canvas;
+    @Mock
+    private WiresCanvasView canvasview;
+    @Mock
+    private WiresManager wiresManager;
     @Mock
     private Diagram diagram;
     @Mock
@@ -92,9 +92,6 @@ public class ConnectionAcceptorControlImplTest {
     @Mock
     private Connection connection;
 
-    @Mock
-    private EventSourceMock<CancelCanvasAction> cancelCanvasActionEvent;
-
     private ConnectionAcceptorControlImpl tested;
     private SetConnectionSourceNodeCommand setConnectionSourceNodeCommand;
     private SetConnectionTargetNodeCommand setConnectionTargetNodeCommand;
@@ -104,10 +101,11 @@ public class ConnectionAcceptorControlImplTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
+        when(canvas.getWiresManager()).thenReturn(wiresManager);
+        when(canvas.getView()).thenReturn(canvasview);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(canvasHandler.getCanvas()).thenReturn(canvas);
         when(canvasHandler.getAbstractCanvas()).thenReturn(canvas);
-        when(canvas.getView()).thenReturn(canvasView);
         when(edge.getContent()).thenReturn(edgeContent);
         when(edgeContent.getSourceConnection()).thenReturn(Optional.empty());
         when(edgeContent.getTargetConnection()).thenReturn(Optional.empty());
@@ -141,7 +139,8 @@ public class ConnectionAcceptorControlImplTest {
                                   eq(setConnectionTargetNodeCommand))).thenReturn(result);
         when(commandManager.execute(eq(canvasHandler),
                                     eq(setConnectionTargetNodeCommand))).thenReturn(result);
-        this.tested = new ConnectionAcceptorControlImpl(canvasCommandFactory, cancelCanvasActionEvent);
+        this.tested = new ConnectionAcceptorControlImpl(canvasCommandFactory,
+                                                        highlight);
         this.tested.setCommandManagerProvider(() -> commandManager);
     }
 
@@ -150,11 +149,12 @@ public class ConnectionAcceptorControlImplTest {
         tested.init(canvasHandler);
         assertEquals(canvasHandler,
                      tested.getCanvasHandler());
-        verify(canvasView,
+        verify(highlight, times(1)).setCanvasHandler(eq(canvasHandler));
+        verify(wiresManager,
                times(1)).setConnectionAcceptor(any(IConnectionAcceptor.class));
-        verify(canvasView,
+        verify(wiresManager,
                never()).setDockingAcceptor(any(IDockingAcceptor.class));
-        verify(canvasView,
+        verify(wiresManager,
                never()).setContainmentAcceptor(any(IContainmentAcceptor.class));
     }
 
@@ -177,6 +177,7 @@ public class ConnectionAcceptorControlImplTest {
                      setConnectionSourceNodeCommand.getEdge());
         assertEquals(connection,
                      setConnectionSourceNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -194,6 +195,7 @@ public class ConnectionAcceptorControlImplTest {
         verify(commandManager,
                never()).execute(any(AbstractCanvasHandler.class),
                                 any(SetConnectionSourceNodeCommand.class));
+        verify(highlight, never()).unhighLight();
     }
 
     @Test
@@ -215,6 +217,7 @@ public class ConnectionAcceptorControlImplTest {
                      setConnectionTargetNodeCommand.getEdge());
         assertEquals(connection,
                      setConnectionTargetNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -232,6 +235,7 @@ public class ConnectionAcceptorControlImplTest {
         verify(commandManager,
                never()).execute(any(AbstractCanvasHandler.class),
                                 any(SetConnectionSourceNodeCommand.class));
+        verify(highlight, never()).unhighLight();
     }
 
     @Test
@@ -253,6 +257,7 @@ public class ConnectionAcceptorControlImplTest {
                      setConnectionSourceNodeCommand.getEdge());
         assertEquals(connection,
                      setConnectionSourceNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -274,6 +279,7 @@ public class ConnectionAcceptorControlImplTest {
                      setConnectionTargetNodeCommand.getEdge());
         assertEquals(connection,
                      setConnectionTargetNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -285,17 +291,12 @@ public class ConnectionAcceptorControlImplTest {
                                                   connection);
         assertTrue(allow);
         verify(commandManager,
-               times(1)).execute(eq(canvasHandler),
-                                 eq(setConnectionSourceNodeCommand));
+               never()).execute(eq(canvasHandler),
+                                eq(setConnectionSourceNodeCommand));
         verify(commandManager,
                never()).allow(any(AbstractCanvasHandler.class),
                               any(SetConnectionSourceNodeCommand.class));
-        assertEquals(node,
-                     setConnectionSourceNodeCommand.getNode());
-        assertEquals(edge,
-                     setConnectionSourceNodeCommand.getEdge());
-        assertEquals(connection,
-                     setConnectionSourceNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -306,18 +307,10 @@ public class ConnectionAcceptorControlImplTest {
                                                   edge,
                                                   connection);
         assertTrue(allow);
-        verify(commandManager,
-               times(1)).execute(eq(canvasHandler),
-                                 eq(setConnectionTargetNodeCommand));
         verify(commandManager,
                never()).allow(any(AbstractCanvasHandler.class),
                               any(SetConnectionTargetNodeCommand.class));
-        assertEquals(node,
-                     setConnectionTargetNodeCommand.getNode());
-        assertEquals(edge,
-                     setConnectionTargetNodeCommand.getEdge());
-        assertEquals(connection,
-                     setConnectionTargetNodeCommand.getConnection());
+        verify(highlight, times(1)).unhighLight();
     }
 
     @Test
@@ -359,10 +352,7 @@ public class ConnectionAcceptorControlImplTest {
         // New default connection for a graph element.
         Element element = mock(Element.class);
         View<?> content = mock(View.class);
-        BoundsImpl bounds = new BoundsImpl(new BoundImpl(0d,
-                                                         0d),
-                                           new BoundImpl(10d,
-                                                         20d));
+        Bounds bounds = Bounds.create(0d, 0d, 10d, 20d);
         when(element.getContent()).thenReturn(content);
         when(content.getBounds()).thenReturn(bounds);
         MagnetConnection c1 =
@@ -408,18 +398,4 @@ public class ConnectionAcceptorControlImplTest {
         assertNull(ConnectionAcceptorControlImpl.createConnection(null,
                                                                   null));
     }
-
-    @Test
-    public void onKeyDownEventTest() {
-        InOrder inOrder = inOrder(cancelCanvasActionEvent);
-
-        tested.init(canvasHandler);
-        tested.onKeyDownEvent(KeyboardEvent.Key.ESC);
-        tested.onKeyDownEvent(KeyboardEvent.Key.CONTROL);
-        tested.onKeyDownEvent(KeyboardEvent.Key.ARROW_RIGHT);
-
-        inOrder.verify(cancelCanvasActionEvent, times(1)).fire(any(CancelCanvasAction.class));
-        inOrder.verify(cancelCanvasActionEvent, never()).fire(any(CancelCanvasAction.class));
-        inOrder.verify(cancelCanvasActionEvent, never()).fire(any(CancelCanvasAction.class));
-    }
 }
