@@ -52,9 +52,9 @@ public class ActivityDataIOEditor implements ActivityDataIOEditorView.Presenter
     @Inject
     ActivityDataIOEditorView view;
 
-    private List<String> dataTypes = new ArrayList<String>();
+    private List<String> dataTypes = new ArrayList<>();
 
-    private List<String> dataTypeDisplayNames = new ArrayList<String>();
+    private List<String> dataTypeDisplayNames = new ArrayList<>();
 
     private AssignmentData assignmentData;
 
@@ -68,7 +68,7 @@ public class ActivityDataIOEditor implements ActivityDataIOEditorView.Presenter
     }
 
     @Override
-    public void handleSaveClick() {
+    public void handleOkClick() {
         if (callback != null) {
             AssignmentData data = new AssignmentData(view.getInputAssignmentData(),
                                                      view.getOutputAssignmentData(),
@@ -126,7 +126,7 @@ public class ActivityDataIOEditor implements ActivityDataIOEditorView.Presenter
     }
 
     public void setDisallowedPropertyNames(final List<String> disallowedPropertyNames) {
-        Set<String> propertyNames = new HashSet<String>();
+        Set<String> propertyNames = new HashSet<>();
         if (disallowedPropertyNames != null) {
             for (String name : disallowedPropertyNames) {
                 propertyNames.add(name.toLowerCase());
@@ -148,29 +148,27 @@ public class ActivityDataIOEditor implements ActivityDataIOEditorView.Presenter
         view.setOutputAssignmentRows(outputAssignmentRows);
     }
 
+    public void setReadOnly(final boolean readOnly) {
+        view.setReadOnly(readOnly);
+    }
+
     public void show() {
         view.showView();
     }
 
     @Override
     public ListBoxValues.ValueTester dataTypesTester() {
-        return new ListBoxValues.ValueTester() {
-            public String getNonCustomValueForUserString(String userValue) {
-                if (assignmentData != null) {
-                    return assignmentData.getDataTypeDisplayNameForUserString(userValue);
-                } else {
-                    return null;
-                }
+        return userValue -> {
+            if (assignmentData != null) {
+                return assignmentData.getDataTypeDisplayNameForUserString(userValue);
+            } else {
+                return null;
             }
         };
     }
 
     @Override
     public ListBoxValues.ValueTester processVarTester() {
-        return new ListBoxValues.ValueTester() {
-            public String getNonCustomValueForUserString(String userValue) {
-                return null;
-            }
-        };
+        return userValue -> null;
     }
 }
