@@ -62,7 +62,6 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
     ListBoxValues dataTypeListBoxValues;
 
     private VariablesEditorWidgetView view;
-    private Variable.VariableType variableType = Variable.VariableType.PROCESS;
     private List<String> dataTypes = new ArrayList<>();
     private Graph graph;
     private Path path;
@@ -127,9 +126,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         if (as.isEmpty()) {
             view.setTableDisplayStyle();
         }
-        VariableRow newVariable = new VariableRow();
-        newVariable.setVariableType(variableType);
-        as.add(newVariable);
+        as.add(createVariableRow());
         VariableListItemWidgetView widget = view.getVariableWidget(view.getVariableRowsCount() - 1);
 
         widget.setDataTypes(dataTypeListBoxValues);
@@ -202,16 +199,30 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         List<Variable> variables = new ArrayList<>();
         for (VariableRow row : variableRows) {
             if (row.getName() != null && row.getName().length() > 0) {
-                variables.add(new Variable(row,
-                                           mapDataTypeDisplayNamesToNames));
+                String dataType = getRowDataType(row);
+                variables.add(new Variable(row.getName(),
+                                           row.getVariableType(),
+                                           dataType,
+                                           row.getCustomDataType(),
+                                           row.getTags()));
             }
         }
 
         return StringUtils.getStringForList(variables);
     }
 
+    private String getRowDataType(VariableRow row) {
+        if (row.getDataTypeDisplayName() != null &&
+                mapDataTypeDisplayNamesToNames.containsKey(row.getDataTypeDisplayName())) {
+            return mapDataTypeDisplayNamesToNames.get(row.getDataTypeDisplayName());
+        } else {
+            return row.getDataTypeDisplayName();
+        }
+    }
+
     /**
      * Tests whether a Row name occurs more than once in the list of rows
+     *
      * @param name
      * @return
      */
@@ -246,7 +257,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
     public void removeVariable(final VariableRow variableRow) {
 
         if (isBoundToNodes(variableRow.getName())) {
-            errorPopupPresenter.showMessage(StunnerFormsClientFieldsConstants.INSTANCE.DeleteDiagramVariableError());
+            errorPopupPresenter.showMessage(StunnerFormsClientFieldsConstants.CONSTANTS.DeleteDiagramVariableError());
         } else {
             view.getVariableRows().remove(variableRow);
             doSave();
@@ -289,8 +300,14 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         }
     }
 
-    public static Set<String> getDefaultTagsSet() {
-        return  defaultTagsSet;
+    static VariableRow createVariableRow() {
+        VariableRow newVariable = new VariableRow();
+        newVariable.setVariableType(Variable.VariableType.PROCESS);
+        newVariable.setDataTypeDisplayName("Object");
+        return newVariable;
     }
 
+    public static Set<String> getDefaultTagsSet() {
+        return defaultTagsSet;
+    }
 }
