@@ -19,7 +19,7 @@ package org.kie.workbench.common.stunner.cm.backend.forms.gen.util;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
-import org.kie.workbench.common.stunner.bpmn.backend.forms.gen.util.FormGenerationModelProviderHelper;
+import org.kie.workbench.common.stunner.bpmn.project.backend.forms.gen.util.FormGenerationModelProviderHelper;
 import org.kie.workbench.common.stunner.cm.backend.CaseManagementBackendService;
 
 @Dependent
