@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.cm.client.canvas;
 
 import java.util.Collections;
 import java.util.Optional;
+import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
@@ -26,6 +27,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNViewDefinition;
 import org.kie.workbench.common.stunner.cm.client.shape.CaseManagementShape;
+import org.kie.workbench.common.stunner.cm.client.shape.def.CaseManagementSvgShapeDef;
 import org.kie.workbench.common.stunner.cm.client.shape.view.CaseManagementShapeView;
 import org.kie.workbench.common.stunner.cm.definition.CaseManagementDiagram;
 import org.kie.workbench.common.stunner.core.client.api.ClientDefinitionManager;
@@ -41,6 +43,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.event.registration.Ca
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
+import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
 import org.kie.workbench.common.stunner.core.definition.adapter.PropertyAdapter;
@@ -66,9 +69,9 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.anyDouble;
+import static org.mockito.Matchers.anyObject;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyObject;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -130,6 +133,9 @@ public class CaseManagementCanvasHandlerTest {
     @Mock
     private Transform transform;
 
+    @Mock
+    private BiConsumer viewHandler;
+
     private static final double X = 10.0d;
     private static final double Y = 20.0d;
 
@@ -182,25 +188,44 @@ public class CaseManagementCanvasHandlerTest {
                times(1)).addShape(eq(shape));
     }
 
+    @Test
+    @SuppressWarnings("unchecked")
+    public void checkRegisterNoneShape() {
+        final ShapeFactory factory = mock(ShapeFactory.class);
+        when(factory.newShape(any(CaseManagementDiagram.class))).thenReturn(null);
+
+        final CaseManagementShape shape = makeShape();
+        final Node<View<BPMNViewDefinition>, Edge> node = makeNode("uuid",
+                                                                   shape);
+
+        handler.register(factory,
+                         node,
+                         true);
+
+        verify(canvas,
+               never()).addShape(eq(shape));
+    }
+
     @SuppressWarnings("unchecked")
     private CaseManagementShape makeShape() {
         final CaseManagementShapeView shapeView = mock(CaseManagementShapeView.class);
-        return new CaseManagementShape(shapeView);
+        final CaseManagementSvgShapeDef shapeDef = mock(CaseManagementSvgShapeDef.class);
+        when(shapeDef.viewHandler()).thenReturn(viewHandler);
+        return new CaseManagementShape(shapeView, shapeDef);
     }
 
     @SuppressWarnings("unchecked")
     private Node<View<BPMNViewDefinition>, Edge> makeNode(final String uuid,
                                                           final CaseManagementShape shape) {
         final Node<View<BPMNViewDefinition>, Edge> node = new NodeImpl<>(uuid);
-        node.setContent(new ViewImpl(new CaseManagementDiagram(),
+        node.setContent(new ViewImpl(spy(new CaseManagementDiagram()),
                                      Bounds.create(0d, 0d, 10d, 20d)));
         shape.setUUID(uuid);
         when(canvas.getShape(eq(uuid))).thenReturn(shape);
         when(clientDefinitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.forDefinition()).thenReturn(definitionAdapter);
         when(adapterManager.forProperty()).thenReturn(propertyAdapter);
-        when(definitionAdapter.getMetaProperty(eq(PropertyMetaTypes.NAME),
-                                               anyObject())).thenReturn(PropertyMetaTypes.NAME);
+        when(definitionAdapter.getMetaPropertyField(anyObject(), eq(PropertyMetaTypes.NAME))).thenReturn(("name"));
         when(propertyAdapter.getValue(eq(PropertyMetaTypes.NAME))).thenReturn("name");
         return node;
     }
@@ -335,10 +360,12 @@ public class CaseManagementCanvasHandlerTest {
                                      true,
                                      mutationContext);
 
-        verify(shape.getShapeView(),
+        final CaseManagementShapeView shapeView = (CaseManagementShapeView) shape.getShapeView();
+
+        verify(shapeView,
                times(1)).refresh();
 
-        verify((CaseManagementShapeView) shape.getShapeView(),
+        verify(shapeView,
                times(1)).setLabel(eq(name));
 
         verify(shape,
@@ -349,6 +376,10 @@ public class CaseManagementCanvasHandlerTest {
 
         verify(canvasElementUpdatedEvent,
                times(1)).fire(any());
+
+        verify(viewHandler,
+               times(1)).accept(eq(node.getContent().getDefinition()),
+                                eq(shapeView));
     }
 
     @Test
@@ -370,10 +401,12 @@ public class CaseManagementCanvasHandlerTest {
                                      true,
                                      mutationContext);
 
-        verify(shape.getShapeView(),
+        final CaseManagementShapeView shapeView = (CaseManagementShapeView) shape.getShapeView();
+
+        verify(shapeView,
                times(1)).refresh();
 
-        verify((CaseManagementShapeView) shape.getShapeView(),
+        verify(shapeView,
                times(1)).setLabel(eq(name));
 
         verify(shape,
@@ -384,6 +417,10 @@ public class CaseManagementCanvasHandlerTest {
 
         verify(canvasElementUpdatedEvent,
                times(1)).fire(any());
+
+        verify(viewHandler,
+               times(1)).accept(eq(node.getContent().getDefinition()),
+                                eq(shapeView));
     }
 
     @SuppressWarnings("unchecked")
